@@ -1,7 +1,7 @@
 /*
  * info_display.cc
  *
- * Copyright (C) 1995-2000 Kenichi Kourai
+ * Copyright (C) 1995-2001 Kenichi Kourai
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -105,7 +105,7 @@ void InfoDisplay::Draw()
   xp[2].x = 0;
   xp[2].y = rc.height - 1;
 
-  XSetForeground(display, gc, black.pixel);
+  XSetForeground(display, gc, darkGrey.pixel);
   XDrawLines(display, frame, gc, xp, 3, CoordModeOrigin);
 
   xp[0].x = rc.width - 3;
@@ -115,7 +115,7 @@ void InfoDisplay::Draw()
   xp[2].x = 1;
   xp[2].y = rc.height - 3;
 
-  XSetForeground(display, gc, lightGray.pixel);
+  XSetForeground(display, gc, gray.pixel);
   XDrawLines(display, frame, gc, xp, 3, CoordModeOrigin);
 
   xp[0].x = rc.width - 2;
