@@ -1,7 +1,7 @@
 /*
  * parse.h
  *
- * Copyright (C) 1995-2000 Kenichi Kourai
+ * Copyright (C) 1995-2001 Kenichi Kourai
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,11 +44,6 @@ struct VariableTable {
   void* var;
 };
 
-struct FuncTable {
-  char* name;
-  FuncNumber num;
-};
-
 struct AttrStream {
   unsigned long attr;		// frame attribute
   Bool act;			// act direction (True:+, False:-)
