@@ -1,7 +1,7 @@
 /*
  * taskbar.cc
  *
- * Copyright (C) 1995-2000 Kenichi Kourai
+ * Copyright (C) 1995-2001 Kenichi Kourai
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -148,6 +148,9 @@ Taskbar::Taskbar(Qvwm* qvWm, int width, unsigned int rows)
 		       0, CopyFromParent, InputOutput, CopyFromParent,
 		       valueMask, &attributes);
 
+  XMapWindow(display, w);
+  XMapWindow(display, tbox);
+
   if (TaskbarImage) {
     imgTaskbar = CreateImageFromFile(TaskbarImage, timer);
     if (imgTaskbar) {
@@ -187,7 +190,6 @@ Taskbar::~Taskbar()
 void Taskbar::MapTaskbar()
 {
   XMapWindow(display, frame);
-  XMapWindow(display, w);
 
   RaiseTaskbar();
 
@@ -196,8 +198,6 @@ void Taskbar::MapTaskbar()
 
   rootQvwm->tButton->MapButton();         // Start menu
 
-  XMapWindow(display, tbox);
-
   if (TaskbarAutoHide) {
     BasicCallback* cb;
     cb = new Callback<Taskbar>(this, &Taskbar::HideTaskbar);
@@ -321,6 +321,9 @@ void Taskbar::MoveTaskbar(const Point& ptRoot)
   Rect rcRoot = rootQvwm->GetRect();
   Bool pointer = False;
 
+  if (DisableDesktopChange)
+    return;
+
   /*
    * There is parts that cannot let taskbar to move.
    */
@@ -422,6 +425,9 @@ void Taskbar::ResizeTaskbar(const Point& ptRoot)
   Bool pointer = False;
   int ctype;
 
+  if (DisableDesktopChange)
+    return;
+
   if (!OpaqueResize) {
     XGrabServer(display);
     XDrawRectangle(display, root, gcXor,
@@ -708,7 +714,7 @@ void Taskbar::DrawTaskbarFrame()
     XSetForeground(display, gc, darkGray.pixel);
     XDrawLine(display, frame, gc, rc[TOP].x, rc[TOP].height-2,
 	      rc[TOP].width-1, rc[TOP].height-2);
-    XSetForeground(display, gc, black.pixel);
+    XSetForeground(display, gc, darkGrey.pixel);
     XDrawLine(display, frame, gc, rc[TOP].x, rc[TOP].height-1,
 	      rc[TOP].width-1, rc[TOP].height-1);
     break;
@@ -717,7 +723,7 @@ void Taskbar::DrawTaskbarFrame()
     XSetForeground(display, gc, darkGray.pixel);
     XDrawLine(display, frame, gc, rc[LEFT].width-2, rc[LEFT].y,
 	      rc[LEFT].width-2, rc[LEFT].height-1);
-    XSetForeground(display, gc, black.pixel);
+    XSetForeground(display, gc, darkGrey.pixel);
     XDrawLine(display, frame, gc, rc[LEFT].width-1, rc[LEFT].y,
 	      rc[LEFT].width-1, rc[LEFT].height-1);
     break;
@@ -1179,6 +1185,8 @@ void Taskbar::RedrawAllTaskbarButtons()
   StartButton *sButton = (StartButton *)rootQvwm->tButton;
   int x, y;
   Point offFrame;
+  Rect rcCurPage(paging->origin.x, paging->origin.y,
+		 rcScreen.width, rcScreen.height);
 
   // get offset between frame and w
   switch (pos) {
@@ -1236,10 +1244,18 @@ void Taskbar::RedrawAllTaskbarButtons()
   }
 
   // Count the number of taskbar buttons.
-  for (tmpQvwm = i.GetHead(); tmpQvwm; tmpQvwm = i.GetNext())
+  for (tmpQvwm = i.GetHead(); tmpQvwm; tmpQvwm = i.GetNext()) {
     if (!tmpQvwm->CheckFlags(TRANSIENT) && !tmpQvwm->CheckFlags(NO_TBUTTON) &&
-	(tmpQvwm->CheckMapped() || tmpQvwm->CheckStatus(MINIMIZE_WINDOW)))
+	(tmpQvwm->CheckMapped() || tmpQvwm->CheckStatus(MINIMIZE_WINDOW))) {
+      if (TaskbarButtonInScr) {
+	// count only taskbar buttons in the current page
+	if (!Intersect(tmpQvwm->GetRect(), rcCurPage))
+	  continue;
+      }
+
       buttonNum++;
+    }
+  }
      
   if (buttonNum == 0)
     return;
@@ -1285,6 +1301,14 @@ void Taskbar::RedrawAllTaskbarButtons()
 
     TaskbarButton* tb = tmpQvwm->tButton;
 
+    if (TaskbarButtonInScr) {
+      // show only taskbar buttons in the current page
+      if (!Intersect(tmpQvwm->GetRect(), rcCurPage)) {
+	tb->MoveResizeButton(Rect(-1, -1, 1, 1));  // hide
+	continue;
+      }
+    }
+
     switch (pos) {
     case BOTTOM:
     case TOP:
